![Screenshot_20210827-111909-removebg-preview](https://user-images.githubusercontent.com/74001397/131107876-db415339-0c1d-4876-8665-fe9b76c4518c.png)

## Archive Notice
This has been archived for now due to the issue [#124](https://github.com/MarioVilas/googlesearch/issues/124)_ in the googlesearch library

---
> Uh-oh. Looks like they deprecated this API entirely. :(
> 
> ```
> -------------------------------------------------------------------------------
> b'<!doctype html><html itemscope="" itemtype="http://schema.org/WebPage" lang="es"><head><meta http-equiv="Content-Type" content="text/html; charset=UTF-8"><meta content="Google.es permite acceder a la informaci\xc3\xb3n mundial en castellano, catal\xc3\xa1n, gallego, euskara e ingl\xc3\xa9s." name="description"><meta content="noodp, " name="robots"><meta content="/images/branding/googleg/1x/googleg_standard_color_128dp.png" itemprop="image"><title>Google</title><style>#gbar,#guser{font-size:13px;padding-top:1px !important;}#gbar{height:22px}#guser{padding-bottom:7px !important;text-align:right}.gbh,.gbd{border-top:1px solid #c9d7f1;font-size:1px}.gbh{height:0;position:absolute;top:24px;width:100%}@media all{.gb1{height:22px;margin-right:.5em;vertical-align:top}#gbar{float:left}}a.gb1,a.gb4{text-decoration:underline !important}a.gb1,a.gb4{color:#00c !important}.gbi .gb4{color:#dd8e27 !important}.gbf .gb4{color:#900 !important}\n</style><style>body,td,a,p,.h{font-family:sans-serif}body{background:#fff;color:#1f1f1f;margin:0}#gog{padding:3px 10px 0}td{line-height:.8em}.gac_m td{line-height:17px}form{margin-bottom:20px}.h{color:#1967d2}.lst{height:32px}.lst{margin-bottom:.2em;padding:4px 5px 0 5px;vertical-align:bottom;width:496px;font:17px sans-serif}.lst:focus{outline:none}.lsb{border:1px solid;border-color:#dadce0 #70757a #70757a #dadce0;height:1.85em !important;font:15px sans-serif;vertical-align:top}.lsb:active{background:#dadce0}em{font-weight:bold;font-style:normal}input{font-family:inherit}a{color:#681da8;text-decoration:none}a:hover,a:active{text-decoration:underline}.fl a{color:#1967d2}a:visited{color:#681da8}td.fl a{font-size:11px}</style></head><body bgcolor="#fff"><style>.wSPnSc{font-size:16px;padding:12px 16px 12px 16px}.mFqrlc{font-weight:bold;margin-bottom:12px}</style><div class="wSPnSc"><div class="mFqrlc">Actualiza tu navegador</div><span>Tu navegador ya no es compatible. Para continuar con tu b\xc3\xbasqueda, actual\xc3\xadzalo a una versi\xc3\xb3n reciente.</span> <a href="https://support.google.com/websearch/answer/16515119"><span>M\xc3\xa1s informaci\xc3\xb3n</span></a></div></body></html>'
> -------------------------------------------------------------------------------
> ```
> 
> Not sure I can fix this one :( we'll see... 

 _Originally posted by @MarioVilas in [#124](https://github.com/MarioVilas/googlesearch/issues/124#issuecomment-3518407650)_

 ---
 
![OS](https://img.shields.io/badge/OS-GNU%2FLinux-red?style=flat&logo=linux)
![OS](https://img.shields.io/badge/OS-Windows-blue?style=flat&logo=Windows)
![GitHub](https://img.shields.io/github/license/rly0nheart/oxdork?style=flat&logo=github)
![GitHub release (latest by date including pre-releases)](https://img.shields.io/github/v/release/rly0nheart/oxdork?include_prereleases&style=flat&logo=github)
![GitHub repo size](https://img.shields.io/github/repo-size/rly0nheart/oxdork?style=flat&logo=github)



![Screenshot_20230207_124512](https://user-images.githubusercontent.com/74001397/217223738-9a432f18-a30e-4121-87ca-09c7dad081e3.png)

oxDork uses Google dorking techniques and Google dorks to find security holes and misconfigurations in web servers.


# Wiki
Check the *Installation guide*, *Usage*, and *a
Available options* on the [wiki](https://github.com/rly0nheart/oxdork/wiki/)


# Queries
A collection of 5,568 common dork queries [here](https://github.com/rly0nheart/oxdork/tree/master/dork_queries)


# Support
<a href="https://www.buymeacoffee.com/rly0nheart" target="_blank"><img src="https://cdn.buymeacoffee.com/buttons/default-orange.png" alt="Buy Me A Coffee" height="41" width="174"></a>
